@@ -1,18 +1,18 @@
 package Data::Verifier::Results;
+
 use Moose;
-use MooseX::AttributeHelpers;
 use MooseX::Storage;
 
 with 'MooseX::Storage::Deferred';
 
 has 'fields' => (
-    metaclass => 'Collection::Hash',
-    is => 'rw',
+    is  => 'rw',
     isa => 'HashRef',
+    traits => [ 'Hash' ],
     default => sub { {} },
-    provides => {
-        get     => 'get_field',
-        set     => 'set_field'
+    handles => {
+        get_field => 'get',
+        set_field => 'set'
     }
 );
 
@@ -179,10 +179,9 @@ or coercions.
 
 Returns the number of valid fields in this Results.
 
-=head2 values
+=head2 valids
 
-Returns a hashref of all the fields this profiled verified as the keys and
-the values that remain after verification.
+Returns a list of valid field names in the results.
 
 =head2 delete_value ($name)
 
@@ -275,4 +274,4 @@ This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
 by the Free Software Foundation; or the Artistic License.
 
-See http://dev.perl.org/licenses/ for more information.
\ No newline at end of file
+See http://dev.perl.org/licenses/ for more information.
